==> igniteui-react-16.16.2.tgz: package/esm5/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var ButtonBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ButtonBase, _super);
    function ButtonBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.clicked = null;
        _this.g = new WCNativeHelper();
        _this.j = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    ButtonBase.prototype.clickedChanged = function () {
        var _this = this;
        if (this.clicked != null) {
            this.h.g("click", function (a) { return _this.clicked(_this, VoidEventArgs.b(a)); }, false);
        }
        else {
            this.h.h("click");
        }
    };
    Object.defineProperty(ButtonBase.prototype, "h", {
        get: function () {
            return this.g;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "nativeElement", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g.d = this.j;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "b", {
        get: function () {
            var ret_ = this.h.c("type");
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, EnumUtil.parse(ButtonBaseType_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "n", {
        get: function () {
            var ret_ = this.h.c("href");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("href", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "m", {
        get: function () {
            var ret_ = this.h.c("download");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("download", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "a", {
        get: function () {
            var ret_ = this.h.c("target");
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, EnumUtil.parse(ButtonBaseTarget_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("target", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "o", {
        get: function () {
            var ret_ = this.h.c("rel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("rel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "i", {
        get: function () {
            var ret_ = this.h.c("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "l", {
        get: function () {
            var ret_ = this.h.c("ariaLabel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.i("ariaLabel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "c", {
        get: function () {
            var ret_ = this.h.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.h.g("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.h("focus");
        }
    };
    ButtonBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.h.g("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.h("blur");
        }
    };
    ButtonBase.prototype.t = function (a) {
        this.nativeElement.focusComponent(a);
    };
    ButtonBase.prototype.q = function () {
        this.nativeElement.blurComponent();
    };
    ButtonBase.$t = markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
}(BaseElement));
export { ButtonBase };

==> igniteui-react-18.6.0.tgz: package/esm5/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var ButtonBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ButtonBase, _super);
    function ButtonBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.clicked = null;
        _this.g = new WCNativeHelper();
        _this.j = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    ButtonBase.prototype.clickedChanged = function () {
        var _this = this;
        if (this.clicked != null) {
            this.h.r("click", function (a) { return _this.clicked(_this, VoidEventArgs.b(a)); }, false);
        }
        else {
            this.h.u("click");
        }
    };
    Object.defineProperty(ButtonBase.prototype, "h", {
        get: function () {
            return this.g;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "nativeElement", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g.o = this.j;
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(ButtonBase.prototype, "b", {
        get: function () {
            var ret_ = this.h.n("type");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, this.h.f(ButtonBaseType_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.h.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "n", {
        get: function () {
            var ret_ = this.h.n("href");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("href", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "m", {
        get: function () {
            var ret_ = this.h.n("download");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("download", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "a", {
        get: function () {
            var ret_ = this.h.n("target");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, this.h.f(ButtonBaseTarget_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.h.v("target", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "o", {
        get: function () {
            var ret_ = this.h.n("rel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("rel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "i", {
        get: function () {
            var ret_ = this.h.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.h.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "k", {
        get: function () {
            var ret_ = this.h.n("form");
            return ret_;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ButtonBase.prototype, "c", {
        get: function () {
            var ret_ = this.h.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.h.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.h.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    ButtonBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.h.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.u("focus");
        }
    };
    ButtonBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.h.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.h.u("blur");
        }
    };
    ButtonBase.prototype.u = function (a) {
        this.nativeElement.focus(this.h.i(a));
    };
    ButtonBase.prototype.r = function () {
        this.nativeElement.click();
    };
    ButtonBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    ButtonBase.$t = markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
}(BaseElement));
export { ButtonBase };
